@@ -182,7 +182,7 @@ class AzureBackend(AbstractBackend):
         compute_config.target = model.compute_target
         compute_config.environment = env
 
-        workspace = Workspace.get(
+        workspace = self.get_workspace(
             name=model.project.workspace_name,
             subscription_id=model.project.subscription_id,
             resource_group=model.project.resource_group,
