@@ -4,15 +4,13 @@ import click_spinner
 import zipfile
 import tempfile
 from azureml.core import (
-    Workspace as AzWorkspace,
     Run as AzRun,
     Experiment as AzExperiment,
 )
 
 from energinetml.backend import default_backend as backend
 from energinetml.core.model import Model, TrainedModel
-
-from .utils import discover_model
+from energinetml.cli.utils import discover_model
 
 
 # -- CLI Command -------------------------------------------------------------
